@@ -309,6 +309,13 @@ if (getRversion() >= "2.15.1")
 #'   max_iters = 4
 #' )
 #'
+#' # Check the generated columns
+#' # with `summarize_group_cols()`
+#' summarize_group_cols(
+#'   data = df_folded,
+#'   group_cols = paste0('.folds_', 1:2)
+#' )
+#'
 #' ## Check if additional `extreme_pairing_levels`
 #' ## improve the numerical balance
 #' set.seed(2) # try with seed 1 as well
@@ -669,9 +676,11 @@ run_fold_ <- function(data,
     data <- data %>%
       dplyr::group_by(!!as.name(".folds"))
   } else {
-    # Order fold columns
+    # Order fold columns by their tail number (.folds_'##')
     all_colnames <- colnames(data)
-    fold_colnames <- sort(extract_fold_colnames(data))
+    fold_colnames <- extract_fold_colnames(data)
+    fold_idx_order <- order(as.integer(substring(fold_colnames, 8)))
+    fold_colnames <- fold_colnames[fold_idx_order]  # Sort by tail number
     non_fold_colnames <- setdiff(all_colnames, fold_colnames)
     new_order <- c(non_fold_colnames, fold_colnames)
     data <- data[, new_order]
