@@ -1,4 +1,4 @@
-## ----include=FALSE-------------------------------------------------------
+## ----include=FALSE------------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -9,16 +9,16 @@ knitr::opts_chunk$set(
 options(tibble.print_min = 4L, tibble.print_max = 4L)
 
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  # Uncomment:
 #  # install.packages("groupdata2")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  # Uncomment:
 #  # install.packages("devtools")
 #  # devtools::install_github("LudvigOlsen/groupdata2")
 
-## ----error=FALSE, message=FALSE, warning=FALSE---------------------------
+## ----error=FALSE, message=FALSE, warning=FALSE--------------------------------
 
 # Attaching groupdata2
 library(groupdata2)
@@ -34,13 +34,13 @@ library(knitr)
 # like so: plyr::count()
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 groups <- group_factor(df, 5, method = 'n_dist')
 
 groups
@@ -50,20 +50,20 @@ df$groups <- groups
 df %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df %>% 
   group_by(groups) %>% 
   summarize(mean_age = mean(age)) %>% 
   kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 groups <- group_factor(df, 5, method = 'n_dist', force_equal = TRUE)
 
 groups
@@ -73,26 +73,26 @@ plyr::count(groups) %>%
   kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- head(df, length(groups)) %>%
   mutate(group = groups)
 
 df %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_grouped <- group(df, 5, method = 'n_dist')
 
 df_grouped %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_means <- df %>%
   group(5, method = 'n_dist') %>%
   summarise(mean_age = mean(age))
@@ -100,56 +100,56 @@ df_means <- df %>%
 df_means %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_grouped <- df %>%
   group(5, method = 'n_dist', force_equal = TRUE)
 
 df_grouped %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_list <- splt(df, 5, method = 'n_dist')
 
 df_list %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 v = c(1:6)
 
 splt(v, 3, method = 'n_dist')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_list <- splt(df, 5, method = 'n_dist', force_equal = TRUE)
 
 df_list %>% kable(align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
                 "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3),
+                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
                 "score" = sample(c(1:100), 3*6))
 
 df <- df %>% 
@@ -164,7 +164,7 @@ df$session <- rep(c('1','2', '3'), 6)
 kable(df, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded <- fold(df, 3, method = 'n_dist')
 
 # Order by folds
@@ -175,7 +175,7 @@ kable(df_folded, align = 'c')
 
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded <- fold(df, 3, cat_col = 'diagnosis', method = 'n_dist')
 
 # Order by folds
@@ -185,13 +185,13 @@ df_folded <- df_folded %>%
 kable(df_folded, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded %>% 
   count(.folds, diagnosis) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded <- fold(df, 3, id_col = 'participant', method = 'n_dist')
 
 # Order by folds
@@ -204,13 +204,13 @@ rownames(df_folded) <- NULL
 kable(df_folded, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded %>% 
   count(.folds, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded <- fold(df, 3, cat_col = 'diagnosis', id_col = 'participant', method = 'n_dist')
 
 # Order by folds
@@ -220,16 +220,16 @@ df_folded <- df_folded %>%
 kable(df_folded, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_folded %>% 
   count(.folds, diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
                 "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3),
+                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
                 "score" = sample(c(1:100), 3*6))
 
 df <- df %>% arrange(participant)
@@ -243,7 +243,7 @@ df$session <- rep(c('1','2', '3'), 6)
 kable(df, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned <- partition(df, 0.3, list_out = FALSE)
 
 # Order by partitions
@@ -259,7 +259,7 @@ kable(df_partitioned, align = 'c')
 
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned <- partition(df, 0.3, cat_col = 'diagnosis', list_out = FALSE)
 
 # Order by partitions
@@ -269,13 +269,13 @@ df_partitioned <- df_partitioned %>%
 kable(df_partitioned, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned %>% 
   count(.partitions, diagnosis) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned <- partition(df, 0.5, id_col = 'participant', list_out = FALSE)
 
 # Order by partitions
@@ -285,13 +285,13 @@ df_partitioned <- df_partitioned %>%
 kable(df_partitioned, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned %>% 
   count(.partitions, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned <- partition(df, 0.5, cat_col = 'diagnosis', id_col = 'participant', 
                             list_out = FALSE)
 
@@ -302,19 +302,19 @@ df_partitioned <- df_partitioned %>%
 kable(df_partitioned, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_partitioned %>%
   count(.partitions, diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 set.seed(2)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("participant" = factor(rep(c('1','2', '3', '4', '5', '6'), 3)),
                 "age" = rep(sample(c(1:100), 6), 3),
-                "diagnosis" = rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3),
+                "diagnosis" = factor(rep(c('a', 'b', 'a', 'a', 'b', 'b'), 3)),
                 "score" = sample(c(1:100), 3*6))
 
 df <- df %>% 
@@ -342,7 +342,7 @@ df %>%
 kable(df, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, "min", cat_col = "diagnosis") %>% 
   arrange(diagnosis, participant)
 
@@ -353,7 +353,7 @@ df_balanced %>%
 
 kable(df_balanced, align = 'c')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, "min", cat_col = "diagnosis", id_col = "participant", id_method = "n_rows_c") %>% 
   arrange(diagnosis, participant)
 
@@ -365,13 +365,13 @@ df_balanced %>%
 kable(df_balanced, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced %>% 
   count(diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, "max", cat_col = "diagnosis") %>% 
   arrange(diagnosis, participant)
 
@@ -382,7 +382,7 @@ df_balanced %>%
 
 kable(df_balanced, align = 'c')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, "max", cat_col = "diagnosis", 
                        id_col = "participant", id_method = "n_rows_c") %>% 
   arrange(diagnosis, participant)
@@ -395,13 +395,13 @@ df_balanced %>%
 kable(df_balanced, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced %>% 
   count(diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, 3, cat_col = "diagnosis") %>% 
   arrange(diagnosis, participant)
 
@@ -412,13 +412,13 @@ df_balanced %>%
 
 kable(df_balanced, align = 'c')
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced %>% 
   count(diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced <- balance(df, 3, cat_col = "diagnosis", 
                        id_col = "participant", id_method = "n_rows_c") %>% 
   arrange(diagnosis, participant)
@@ -431,31 +431,31 @@ df_balanced %>%
 kable(df_balanced, align = 'c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_balanced %>% 
   count(diagnosis, participant) %>% 
   kable(align='c')
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df <- data.frame("x"=c(1:12), 
-                "species" = rep(c('cat','pig', 'human'), 4), 
+                "species" = factor(rep(c('cat','pig', 'human'), 4)), 
                 "age" = sample(c(1:100), 12))
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 groups <- group_factor(df, 5, method = 'n_dist', randomize = TRUE)
 
 groups
 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 df_list <- splt(df, 5, method = 'n_dist', randomize = TRUE)
 
 df_list %>% kable(align = 'c')
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 # 
 # Examples to show difference between methods
@@ -533,7 +533,7 @@ v57n6_plot +
 
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 
 
@@ -606,7 +606,7 @@ v117n11_plot +
   
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 
 vec <- c(1:100)
@@ -620,7 +620,6 @@ for (n in c(8,15,20)){
   group_sizes <- plyr::count(group_factor(vec, n, method='greedy'))
 
   data_temp <- data.frame(group_sizes, 'Size' = factor(n))
-
   
   if (exists ('greedy_data')) {
     
@@ -650,7 +649,7 @@ greedy_plot +
 
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 
 vec <- c(1:1000)
@@ -694,7 +693,7 @@ staircase_plot +
 
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 staircase_data <- staircase_data %>%
   group_by(step_size) %>%
@@ -713,7 +712,7 @@ staircase_cumulative_plot +
         axis.text.x = element_text(size=7))
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 
 vec <- c(1:1000)
@@ -727,7 +726,6 @@ for (n in c(2, 5, 11)){
   group_sizes <- plyr::count(group_factor(vec, n, method='primes'))
 
   data_temp <- data.frame(group_sizes, 'start_at' = factor(n))
-
   
   if (exists ('primes_data')) {
     
@@ -757,7 +755,7 @@ primes_plot +
 
 
 
-## ----echo=FALSE----------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 
 primes_data <- primes_data %>%
   group_by(start_at) %>%
